@@ -9,7 +9,6 @@ import textwrap
 from os.path import curdir, join, pardir
 
 import pytest
-from pip._vendor.six import PY2
 
 from pip._internal.cli.status_codes import ERROR, SUCCESS
 from pip._internal.models.index import PyPI, TestPyPI
@@ -24,11 +23,7 @@ from tests.lib import (
     need_svn,
     path_to_url,
     pyversion,
-    pyversion_tuple,
     requirements_file,
-    skip_if_not_python2,
-    skip_if_python2,
-    windows_workaround_7667,
 )
 from tests.lib.filesystem import make_socket_file
 from tests.lib.local_repos import local_checkout
@@ -168,7 +163,6 @@ def test_pep518_with_namespace_package(script, data, common_wheels):
     )
 
 
-@pytest.mark.timeout(60)
 @pytest.mark.parametrize('command', ('install', 'wheel'))
 @pytest.mark.parametrize('package', ('pep518_forkbomb',
                                      'pep518_twin_forkbombs_first',
@@ -196,16 +190,10 @@ def test_pip_second_command_line_interface_works(
     """
     # Re-install pip so we get the launchers.
     script.pip_install_local('-f', common_wheels, pip_src)
-    # On old versions of Python, urllib3/requests will raise a warning about
-    # the lack of an SSLContext.
-    kwargs = {'expect_stderr': deprecated_python}
-    if pyversion_tuple < (2, 7, 9):
-        kwargs['expect_stderr'] = True
-
-    args = ['pip{pyversion}'.format(**globals())]
+    args = [f'pip{pyversion}']
     args.extend(['install', 'INITools==0.2'])
     args.extend(['-f', data.packages])
-    result = script.run(*args, **kwargs)
+    result = script.run(*args)
     dist_info_folder = (
         script.site_packages /
         'INITools-0.2.dist-info'
@@ -533,7 +521,7 @@ def test_hashed_install_failure(script, tmpdir):
 
 def assert_re_match(pattern, text):
     assert re.search(pattern, text), (
-        "Could not find {!r} in {!r}".format(pattern, text)
+        f"Could not find {pattern!r} in {text!r}"
     )
 
 
@@ -584,7 +572,29 @@ def test_install_from_local_directory_with_symlinks_to_directories(
     result.did_create(dist_info_folder)
 
 
-@pytest.mark.skipif("sys.platform == 'win32' or sys.version_info < (3,)")
+def test_install_from_local_directory_with_in_tree_build(
+    script, data, with_wheel
+):
+    """
+    Test installing from a local directory with --use-feature=in-tree-build.
+    """
+    to_install = data.packages.joinpath("FSPkg")
+    args = ["install", "--use-feature=in-tree-build", to_install]
+
+    in_tree_build_dir = to_install / "build"
+    assert not in_tree_build_dir.exists()
+    result = script.pip(*args)
+    fspkg_folder = script.site_packages / 'fspkg'
+    dist_info_folder = (
+        script.site_packages /
+        'FSPkg-0.1.dev0.dist-info'
+    )
+    result.did_create(fspkg_folder)
+    result.did_create(dist_info_folder)
+    assert in_tree_build_dir.exists()
+
+
+@pytest.mark.skipif("sys.platform == 'win32'")
 def test_install_from_local_directory_with_socket_file(
     script, data, tmpdir, with_wheel
 ):
@@ -630,9 +640,9 @@ def test_editable_install__local_dir_no_setup_py(
 
     msg = result.stderr
     if deprecated_python:
-        assert 'File "setup.py" not found. ' in msg
+        assert 'File "setup.py" or "setup.cfg" not found. ' in msg
     else:
-        assert msg.startswith('ERROR: File "setup.py" not found. ')
+        assert msg.startswith('ERROR: File "setup.py" or "setup.cfg" not found. ')
     assert 'pyproject.toml' not in msg
 
 
@@ -652,28 +662,13 @@ def test_editable_install__local_dir_no_setup_py_with_pyproject(
 
     msg = result.stderr
     if deprecated_python:
-        assert 'File "setup.py" not found. ' in msg
+        assert 'File "setup.py" or "setup.cfg" not found. ' in msg
     else:
-        assert msg.startswith('ERROR: File "setup.py" not found. ')
+        assert msg.startswith('ERROR: File "setup.py" or "setup.cfg" not found. ')
     assert 'A "pyproject.toml" file was found' in msg
 
 
-@skip_if_not_python2
-@pytest.mark.xfail
-def test_install_argparse_shadowed(script):
-    # When argparse is in the stdlib, we support installing it
-    # even though that's pretty useless because older packages did need to
-    # depend on it, and not having its metadata will cause pkg_resources
-    # requirements checks to fail // trigger easy-install, both of which are
-    # bad.
-    # XXX: Note, this test hits the outside-environment check, not the
-    # in-stdlib check, because our tests run in virtualenvs...
-    result = script.pip('install', 'argparse>=1.4')
-    assert "Not uninstalling argparse" in result.stdout
-
-
 @pytest.mark.network
-@skip_if_python2
 def test_upgrade_argparse_shadowed(script):
     # If argparse is installed - even if shadowed for imported - we support
     # upgrading it and properly remove the older versions files.
@@ -745,11 +740,10 @@ def test_install_using_install_option_and_editable(script, tmpdir):
     """
     folder = 'script_folder'
     script.scratch_path.joinpath(folder).mkdir()
-    url = 'git+git://github.com/pypa/pip-test-package'
+    url = local_checkout('git+git://github.com/pypa/pip-test-package', tmpdir)
     result = script.pip(
-        'install', '-e', '{url}#egg=pip-test-package'
-        .format(url=local_checkout(url, tmpdir)),
-        '--install-option=--script-dir={folder}'.format(**locals()),
+        'install', '-e', f'{url}#egg=pip-test-package',
+        f'--install-option=--script-dir={folder}',
         expect_stderr=True)
     script_file = (
         script.venv / 'src' / 'pip-test-package' /
@@ -761,7 +755,6 @@ def test_install_using_install_option_and_editable(script, tmpdir):
 @pytest.mark.xfail
 @pytest.mark.network
 @need_mercurial
-@windows_workaround_7667
 def test_install_global_option_using_editable(script, tmpdir):
     """
     Test using global distutils options, but in an editable installation
@@ -817,10 +810,7 @@ def test_install_folder_using_slash_in_the_end(script, with_wheel):
     pkg_path = script.scratch_path / 'mock'
     pkg_path.joinpath("setup.py").write_text(mock100_setup_py)
     result = script.pip('install', 'mock' + os.path.sep)
-    dist_info_folder = (
-        script.site_packages /
-        'mock-100.1.dist-info'
-    )
+    dist_info_folder = script.site_packages / 'mock-100.1.dist-info'
     result.did_create(dist_info_folder)
 
 
@@ -833,10 +823,7 @@ def test_install_folder_using_relative_path(script, with_wheel):
     pkg_path = script.scratch_path / 'initools' / 'mock'
     pkg_path.joinpath("setup.py").write_text(mock100_setup_py)
     result = script.pip('install', Path('initools') / 'mock')
-    dist_info_folder = (
-        script.site_packages /
-        'mock-100.1.dist-info'.format(**globals())
-    )
+    dist_info_folder = script.site_packages / 'mock-100.1.dist-info'
     result.did_create(dist_info_folder)
 
 
@@ -973,7 +960,8 @@ def test_install_nonlocal_compatible_wheel_path(
     assert result.returncode == ERROR
 
 
-def test_install_with_target_and_scripts_no_warning(script, with_wheel):
+@pytest.mark.parametrize('opt', ('--target', '--prefix'))
+def test_install_with_target_or_prefix_and_scripts_no_warning(opt, script, with_wheel):
     """
     Test that installing with --target does not trigger the "script not
     in PATH" warning (issue #5201)
@@ -994,7 +982,7 @@ def test_install_with_target_and_scripts_no_warning(script, with_wheel):
     pkga_path.joinpath("pkga.py").write_text(textwrap.dedent("""
         def main(): pass
     """))
-    result = script.pip('install', '--target', target_dir, pkga_path)
+    result = script.pip('install', opt, target_dir, pkga_path)
     # This assertion isn't actually needed, if we get the script warning
     # the script.pip() call will fail with "stderr not expected". But we
     # leave the assertion to make the intention of the code clearer.
@@ -1041,24 +1029,22 @@ def test_install_package_with_prefix(script, data):
     install_path = (
         distutils.sysconfig.get_python_lib(prefix=rel_prefix_path) /
         # we still test for egg-info because no-binary implies setup.py install
-        'simple-1.0-py{}.egg-info'.format(pyversion)
+        f'simple-1.0-py{pyversion}.egg-info'
     )
     result.did_create(install_path)
 
 
-def test_install_editable_with_prefix(script):
+def _test_install_editable_with_prefix(script, files):
     # make a dummy project
     pkga_path = script.scratch_path / 'pkga'
     pkga_path.mkdir()
-    pkga_path.joinpath("setup.py").write_text(textwrap.dedent("""
-        from setuptools import setup
-        setup(name='pkga',
-              version='0.1')
-    """))
+
+    for fn, contents in files.items():
+        pkga_path.joinpath(fn).write_text(textwrap.dedent(contents))
 
     if hasattr(sys, "pypy_version_info"):
         site_packages = os.path.join(
-            'prefix', 'lib', 'python{}'.format(pyversion), 'site-packages')
+            'prefix', 'lib', f'python{pyversion}', 'site-packages')
     else:
         site_packages = distutils.sysconfig.get_python_lib(prefix='prefix')
 
@@ -1077,6 +1063,50 @@ def test_install_editable_with_prefix(script):
     result.did_create(install_path)
 
 
+@pytest.mark.network
+def test_install_editable_with_target(script):
+    pkg_path = script.scratch_path / 'pkg'
+    pkg_path.mkdir()
+    pkg_path.joinpath("setup.py").write_text(textwrap.dedent("""
+        from setuptools import setup
+        setup(
+            name='pkg',
+            install_requires=['watching_testrunner']
+        )
+    """))
+
+    target = script.scratch_path / 'target'
+    target.mkdir()
+    result = script.pip(
+        'install', '--editable', pkg_path, '--target', target
+    )
+
+    result.did_create(script.scratch / 'target' / 'pkg.egg-link')
+    result.did_create(script.scratch / 'target' / 'watching_testrunner.py')
+
+
+def test_install_editable_with_prefix_setup_py(script):
+    setup_py = """
+from setuptools import setup
+setup(name='pkga', version='0.1')
+"""
+    _test_install_editable_with_prefix(script, {"setup.py": setup_py})
+
+
+def test_install_editable_with_prefix_setup_cfg(script):
+    setup_cfg = """[metadata]
+name = pkga
+version = 0.1
+"""
+    pyproject_toml = """[build-system]
+requires = ["setuptools", "wheel"]
+build-backend = "setuptools.build_meta"
+"""
+    _test_install_editable_with_prefix(
+        script, {"setup.cfg": setup_cfg, "pyproject.toml": pyproject_toml}
+    )
+
+
 def test_install_package_conflict_prefix_and_user(script, data):
     """
     Test installing a package using pip install --prefix --user errors out
@@ -1104,7 +1134,7 @@ def test_install_package_that_emits_unicode(script, data):
     )
     assert (
         'FakeError: this package designed to fail on install' in result.stderr
-    ), 'stderr: {}'.format(result.stderr)
+    ), f'stderr: {result.stderr}'
     assert 'UnicodeDecodeError' not in result.stderr
     assert 'UnicodeDecodeError' not in result.stdout
 
@@ -1312,11 +1342,11 @@ def test_install_subprocess_output_handling(script, data):
 def test_install_log(script, data, tmpdir):
     # test that verbose logs go to "--log" file
     f = tmpdir.joinpath("log.txt")
-    args = ['--log={f}'.format(**locals()),
+    args = [f'--log={f}',
             'install', data.src.joinpath('chattymodule')]
     result = script.pip(*args)
     assert 0 == result.stdout.count("HELLO FROM CHATTYMODULE")
-    with open(f, 'r') as fp:
+    with open(f) as fp:
         # one from egg_info, one from install
         assert 2 == fp.read().count("HELLO FROM CHATTYMODULE")
 
@@ -1339,7 +1369,8 @@ def test_cleanup_after_failed_wheel(script, with_wheel):
     # One of the effects of not cleaning up is broken scripts:
     script_py = script.bin_path / "script.py"
     assert script_py.exists(), script_py
-    shebang = open(script_py, 'r').readline().strip()
+    with open(script_py) as f:
+        shebang = f.readline().strip()
     assert shebang != '#!python', shebang
     # OK, assert that we *said* we were cleaning up:
     # /!\ if in need to change this, also change test_pep517_no_legacy_cleanup
@@ -1410,7 +1441,6 @@ def test_install_no_binary_disables_building_wheels(script, data, with_wheel):
 
 
 @pytest.mark.network
-@windows_workaround_7667
 def test_install_no_binary_builds_pep_517_wheel(script, data, with_wheel):
     to_install = data.packages.joinpath('pep517_setup_and_pyproject')
     res = script.pip(
@@ -1425,7 +1455,6 @@ def test_install_no_binary_builds_pep_517_wheel(script, data, with_wheel):
 
 
 @pytest.mark.network
-@windows_workaround_7667
 def test_install_no_binary_uses_local_backend(
         script, data, with_wheel, tmpdir):
     to_install = data.packages.joinpath('pep517_wrapper_buildsys')
@@ -1466,14 +1495,14 @@ def test_install_editable_with_wrong_egg_name(script, resolver_variant):
     """))
     result = script.pip(
         'install', '--editable',
-        'file://{pkga_path}#egg=pkgb'.format(**locals()),
+        f'file://{pkga_path}#egg=pkgb',
         expect_error=(resolver_variant == "2020-resolver"),
     )
     assert ("Generating metadata for package pkgb produced metadata "
             "for project name pkga. Fix your #egg=pkgb "
             "fragments.") in result.stderr
     if resolver_variant == "2020-resolver":
-        assert "has different name in metadata" in result.stderr, str(result)
+        assert "has inconsistent" in result.stderr, str(result)
     else:
         assert "Successfully installed pkga" in str(result), str(result)
 
@@ -1552,7 +1581,7 @@ def test_install_incompatible_python_requires_editable(script):
     """))
     result = script.pip(
         'install',
-        '--editable={pkga_path}'.format(**locals()),
+        f'--editable={pkga_path}',
         expect_error=True)
     assert _get_expected_error_text() in result.stderr, str(result)
 
@@ -1568,7 +1597,7 @@ def test_install_incompatible_python_requires_wheel(script, with_wheel):
     """))
     script.run(
         'python', 'setup.py', 'bdist_wheel', '--universal',
-        cwd=pkga_path, allow_stderr_warning=PY2,
+        cwd=pkga_path,
     )
     result = script.pip('install', './pkga/dist/pkga-0.1-py2.py3-none-any.whl',
                         expect_error=True)
@@ -1638,6 +1667,9 @@ def test_install_from_test_pypi_with_ext_url_dep_is_blocked(script, index):
     assert error_cause in res.stderr, str(res)
 
 
+@pytest.mark.xfail(
+    reason="No longer possible to trigger the warning with either --prefix or --target"
+)
 def test_installing_scripts_outside_path_prints_warning(script):
     result = script.pip_install_local(
         "--prefix", script.scratch_path, "script_wheel1"
@@ -1669,7 +1701,7 @@ def test_installed_files_recorded_in_deterministic_order(script, data):
     to_install = data.packages.joinpath("FSPkg")
     result = script.pip('install', to_install)
     fspkg_folder = script.site_packages / 'fspkg'
-    egg_info = 'FSPkg-0.1.dev0-py{pyversion}.egg-info'.format(**globals())
+    egg_info = f'FSPkg-0.1.dev0-py{pyversion}.egg-info'
     installed_files_path = (
         script.site_packages / egg_info / 'installed-files.txt'
     )
@@ -1732,10 +1764,10 @@ def test_target_install_ignores_distutils_config_install_prefix(script):
                             'pydistutils.cfg' if sys.platform == 'win32'
                             else '.pydistutils.cfg')
     distutils_config.write_text(textwrap.dedent(
-        '''
+        f'''
         [install]
         prefix={prefix}
-        '''.format(**locals())))
+        '''))
     target = script.scratch_path / 'target'
     result = script.pip_install_local('simplewheel', '-t', target)
 
@@ -1803,8 +1835,8 @@ def test_invalid_index_url_argument(script, shared_data):
                         shared_data.find_links3, "Dinner",
                         expect_error=True)
 
-    assert 'WARNING: The index url "--user" seems invalid, ' \
-           'please provide a scheme.' in result.stderr, str(result)
+    assert ('WARNING: The index url "--user" seems invalid, '
+            'please provide a scheme.') in result.stderr, str(result)
 
 
 def test_valid_index_url_argument(script, shared_data):
@@ -1837,7 +1869,6 @@ def test_install_yanked_file_and_print_warning(script, data):
     assert 'Successfully installed simple-3.0\n' in result.stdout, str(result)
 
 
-@skip_if_python2
 @pytest.mark.parametrize("install_args", [
     (),
     ("--trusted-host", "localhost"),
@@ -1857,7 +1888,7 @@ def test_install_sends_client_cert(install_args, script, cert_factory, data):
         file_response(str(data.packages / "simple-3.0.tar.gz")),
     ]
 
-    url = "https://{}:{}/simple".format(server.host, server.port)
+    url = f"https://{server.host}:{server.port}/simple"
 
     args = ["install", "-vvv", "--cert", cert_path, "--client-cert", cert_path]
     args.extend(["--index-url", url])
@@ -1869,7 +1900,9 @@ def test_install_sends_client_cert(install_args, script, cert_factory, data):
 
     assert server.mock.call_count == 2
     for call_args in server.mock.call_args_list:
-        environ, _ = call_args.args
+        # Legacy: replace call_args[0] with call_args.args
+        # when pip drops support for python3.7
+        environ, _ = call_args[0]
         assert "SSL_CLIENT_CERT" in environ
         assert environ["SSL_CLIENT_CERT"]
 
