@@ -160,7 +160,7 @@ class TestOptionPrecedence(AddFakeCommandMixin):
             main(['--no-cache-dir', 'fake'])
 
 
-class TestUsePEP517Options(object):
+class TestUsePEP517Options:
 
     """
     Test options related to using --use-pep517.
@@ -262,7 +262,7 @@ class TestOptionsInterspersed(AddFakeCommandMixin):
 @contextmanager
 def tmpconfig(option, value, section='global'):
     with NamedTemporaryFile(mode='w', delete=False) as f:
-        f.write('[{}]\n{}={}\n'.format(section, option, value))
+        f.write(f'[{section}]\n{option}={value}\n')
         name = f.name
     try:
         yield name
@@ -275,7 +275,7 @@ class TestCountOptions(AddFakeCommandMixin):
     @pytest.mark.parametrize('option', ('verbose', 'quiet'))
     @pytest.mark.parametrize('value', range(4))
     def test_cli_long(self, option, value):
-        flags = ['--{}'.format(option)] * value
+        flags = [f'--{option}'] * value
         opt1, args1 = main(flags+['fake'])
         opt2, args2 = main(['fake']+flags)
         assert getattr(opt1, option) == getattr(opt2, option) == value
@@ -431,7 +431,7 @@ class TestGeneralOptions(AddFakeCommandMixin):
         assert options1.client_cert == options2.client_cert == 'path'
 
 
-class TestOptionsConfigFiles(object):
+class TestOptionsConfigFiles:
 
     def test_venv_config_file_found(self, monkeypatch):
         # strict limit on the global config files list
